@@ -1,7 +1,7 @@
 package App::GenPericmdCompleterScript;
 
 our $DATE = '2015-08-19'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 use 5.010001;
 use strict;
@@ -399,20 +399,19 @@ sub gen_perinci_cmdline_completer_script {
         File::Slurper::write_text($tmp_unpacked_path, $code);
 
         my $res = App::depak::depak(
-            # tmp, while lcpan still indexes old periscomp
-            exclude_module  => ['JSON', 'JSON::Backend::PP','JSON::Boolean',
-                               'Data::Clean::FromJSON',
-                               'YAML::Old'],
-            exclude_pattern => ['^YAML::Old::.+'],
-            include_module  => ['JSON::PP'],
-
             include_prereq => [sort keys %used_modules],
             input_file     => $tmp_unpacked_path,
             output_file    => $tmp_packed_path,
             overwrite      => 1,
             trace_method   => 'none',
             pack_method    => 'datapack',
-            stripper       => 1,
+
+            stripper         => 1,
+            stripper_pod     => 1,
+            stripper_comment => 1,
+            stripper_ws      => 1,
+            stripper_maintain_linum => 0,
+            stripper_log     => 0,
         );
         return $res unless $res->[0] == 200;
 
@@ -460,7 +459,7 @@ App::GenPericmdCompleterScript - Generate Perinci::CmdLine completer script
 
 =head1 VERSION
 
-This document describes version 0.03 of App::GenPericmdCompleterScript (from Perl distribution App-GenPericmdCompleterScript), released on 2015-08-19.
+This document describes version 0.04 of App::GenPericmdCompleterScript (from Perl distribution App-GenPericmdCompleterScript), released on 2015-08-19.
 
 =head1 FUNCTIONS
 
